@@ -390,25 +390,25 @@ bool SG_Set_OldStyle_Naming(void)
 		{	"Geoprocessing",	"Modules"	},
 		{	"Available Tools",	"Available Modules"	},
 		{	"Can't execute a tool while another runs",		"Can't execute a module while another runs"	},
-		{	"Create Tool Description Files",		"Create Module Description Files"	},
-		{	"Execute Tool",		"Execute Module"	},
+		{	"Create Tool Description Files",		"Create Tool Description Files"	},
+		{	"Execute Tool",		"Execute Tool"	},
 		{	"Executing tool",		"Executing module"	},
-		{	"Find and Run Tool",		"Find and Run Module"	},
+		{	"Find and Run Tool",		"Find and Run Tool"	},
 		{	"Interactive tool execution failed",		"Interactive module execution failed"	},
 		{	"Interactive tool execution has been started",		"Interactive module execution has been started"	},
 		{	"Interactive tool execution has been stopped",		"Interactive module execution has been stopped"	},
-		{	"Load Tool Library",		"Load Module Library"	},
+		{	"Load Tool Library",		"Load Tool Library"	},
 		{	"Please stop tool execution before exiting SAGA.",		"Please stop module execution before exiting SAGA."	},
-		{	"Run Tool",		"Run Module"	},
-		{	"SAGA Tool Libraries",		"SAGA Module Libraries"	},
-		{	"Tool",		"Module"	},
-		{	"Tool Description Source",		"Module Description Source"	},
-		{	"Tool Execution",		"Module Execution"	},
-		{	"Tool Libraries",		"Module Libraries"	},
-		{	"Tool Library",		"Module Library"	},
-		{	"Tool Manager",		"Module Manager"	},
-		{	"Tool execution failed",		"Module execution failed"	},
-		{	"Tool execution succeeded",		"Module execution succeeded"	},
+		{	"Run Tool",		"Run Tool"	},
+		{	"SAGA Tool Libraries",		"SAGA Tool Libraries"	},
+		{	"Tool",		"Tool"	},
+		{	"Tool Description Source",		"Tool Description Source"	},
+		{	"Tool Execution",		"Tool Execution"	},
+		{	"Tool Libraries",		"Tool Libraries"	},
+		{	"Tool Library",		"Tool Library"	},
+		{	"Tool Manager",		"Tool Manager"	},
+		{	"Tool execution failed",		"Tool execution failed"	},
+		{	"Tool execution succeeded",		"Tool execution succeeded"	},
 		{	"Tools",		"Modules"	},
 		{	"cannot execute interactive tool",		"cannot execute interactive module"	},
 		{	"could not execute tool",		"could not execute module"	},
