@@ -580,7 +580,9 @@ public:		///////////////////////////////////////////////
 	bool						DeStandardise				(double Mean, double StdDev);
 
 	int							Get_Gradient_NeighborDir	(int x, int y, bool bDown = true, bool bNoEdges = true)	const;
-	bool						Get_Gradient				(int x, int y, double &Incline, double &Azimuth)		const;
+	bool						Get_Gradient				(int x, int y      , double &Slope, double &Aspect)	const;
+	bool						Get_Gradient				(double x, double y, double &Slope, double &Aspect, TSG_Grid_Resampling Interpolation)	const;
+	bool						Get_Gradient				(const TSG_Point &p, double &Slope, double &Aspect, TSG_Grid_Resampling Interpolation)	const;
 
 
 	//-----------------------------------------------------
@@ -806,6 +808,8 @@ public:		///////////////////////////////////////////////
 protected:	///////////////////////////////////////////////
 
 	virtual bool				On_Update				(void);
+	virtual bool				On_Reload				(void);
+	virtual bool				On_Delete				(void);
 
 
 //---------------------------------------------------------
@@ -1041,10 +1045,18 @@ public:
 
 	CSG_Distance_Weighting &	Get_Weighting		(void)								{	return( m_Weighting );		}
 
+	bool						is_Square			(void)	const	{	return( m_Type == 1 );	}
+	bool						is_Annulus			(void)	const	{	return( m_Type == 2 );	}
+	bool						is_Sector			(void)	const	{	return( m_Type == 3 );	}
+
 	bool						Set_Radius			(double Radius, bool bSquare = false);
 	bool						Set_Annulus			(double inner_Radius, double outer_Radius);
 	bool						Set_Sector			(double Radius, double Direction, double Tolerance);
 
+	double						Get_Radius			(bool bOuter = true)	const	{	return( m_Parms[bOuter ? 0 : 1] );	}
+	double						Get_Direction		(void)					const	{	return( m_Parms[2] );	}
+	double						Get_Tolerance		(void)					const	{	return( m_Parms[3] );	}
+
 	int							Get_Count			(void)	const						{	return( m_Cells.Get_Count() );	}
 
 	int							Get_X				(int Index, int Offset = 0)	const	{	return( Offset + (Index >= 0 && Index < Get_Count() ? m_Cells.Get_Record_byIndex(Index)->asInt(0) : 0) );	}
@@ -1082,6 +1094,10 @@ public:
 
 private:
 
+	int							m_Type;
+
+	double						m_Parms[4];
+
 	CSG_Distance_Weighting		m_Weighting;
 
 	CSG_Table					m_Cells;
