@@ -345,6 +345,9 @@ bool CSG_Grid_Cell_Addressor::Set_Radius(double Radius, bool bSquare)
 {
 	Destroy();
 
+	m_Type		= bSquare ? 1 : 0;
+	m_Parms[0]	= Radius;
+
 	//-----------------------------------------------------
 	if( Radius > 0.0 )
 	{
@@ -383,6 +386,10 @@ bool CSG_Grid_Cell_Addressor::Set_Annulus(double inner_Radius, double outer_Radi
 {
 	Destroy();
 
+	m_Type		= 2;
+	m_Parms[0]	= outer_Radius;
+	m_Parms[1]	= inner_Radius;
+
 	//-----------------------------------------------------
 	if( inner_Radius <= outer_Radius )
 	{
@@ -424,6 +431,11 @@ bool CSG_Grid_Cell_Addressor::Set_Sector(double Radius, double Direction, double
 {
 	Destroy();
 
+	m_Type		= 3;
+	m_Parms[0]	= Radius;
+	m_Parms[2]	= Direction;
+	m_Parms[3]	= Tolerance;
+
 	//-----------------------------------------------------
 	if( Radius > 0.0 )
 	{
