@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: metadata.cpp 2777 2016-02-10 15:04:57Z oconrad $
+ * Version $Id$
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -169,17 +169,6 @@ void CSG_MetaData::Destroy(void)
 }
 
 
-///////////////////////////////////////////////////////////
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-bool CSG_MetaData::is_Valid(void)	const
-{
-	return( this != NULL );
-}
-
-
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
