@@ -206,7 +206,7 @@ void CSG_Parameters::Destroy(void)
 /**
   * Set the responsible data manager for this parameter list.
   * If it is not NULL, the parameter list will perform checks
-  * beforehand module executions, e.g. check if all data sets
+  * beforehand tool executions, e.g. check if all data sets
   * in its parameter list are really loaded.
 */
 //---------------------------------------------------------
@@ -253,6 +253,38 @@ void CSG_Parameters::Set_Description(const CSG_String &String)
 	m_Description	= String;
 }
 
+//---------------------------------------------------------
+/**
+  * Add a reference to the list of references.
+*/
+//---------------------------------------------------------
+void CSG_Parameters::Add_Reference(const CSG_String &Authors, const CSG_String &Year, const CSG_String &Title, const CSG_String &Where, const SG_Char *Link, const SG_Char *Link_Text)
+{
+	CSG_String	Reference	= Authors;
+
+	Reference.Printf("%s (%s): %s. %s", Authors.c_str(), Year.c_str(), Title.c_str(), Where.c_str());
+
+	if( Link && *Link )
+	{
+		Reference	+= CSG_String::Format(" <a href=\"%s\">%s</a>.", Link, Link_Text && *Link_Text ? Link_Text : Link);
+	}
+
+	if( !Reference.is_Empty() )
+	{
+		m_References	+= Reference;
+	}
+}
+
+//---------------------------------------------------------
+/**
+  * Add a reference to the list of references.
+*/
+//---------------------------------------------------------
+void CSG_Parameters::Add_Reference(const CSG_String &Link, const SG_Char *Link_Text)
+{
+	m_References	+= CSG_String::Format("<a href=\"%s\">%s</a>", Link.c_str(), Link_Text && *Link_Text ? Link_Text : Link.c_str());
+}
+
 //---------------------------------------------------------
 /**
   * Enable or disable all parameters.
@@ -1317,7 +1349,10 @@ bool CSG_Parameters::DataObjects_Create(void)
 		}
 		else if( p->Get_Type() == PARAMETER_TYPE_DataObject_Output )
 		{
-			p->Set_Value(DATAOBJECT_NOTSET);
+			if( m_pManager || p->asDataObject() == DATAOBJECT_CREATE )
+			{
+				p->Set_Value(DATAOBJECT_NOTSET);
+			}
 		}
 		else if( p->is_Input() )
 		{
@@ -1427,43 +1462,28 @@ bool CSG_Parameters::DataObjects_Synchronize(void)
 		}
 
 		//-------------------------------------------------
-		else
+		else if( p->is_Output() )
 		{
-			if( p->Get_Type() == PARAMETER_TYPE_Shapes
-			&&  p->asShapes() != DATAOBJECT_NOTSET
-			&&  p->asShapes() != DATAOBJECT_CREATE
-			&&  p->asShapes()->Get_Type() == SHAPE_TYPE_Undefined )
+			if( p->is_DataObject() )
 			{
-				if( m_pManager && !m_pManager->Delete(p->asShapes()) )
+				CSG_Data_Object	*pObject	= p->asDataObject();
+
+				if( pObject != DATAOBJECT_NOTSET
+				&&  pObject != DATAOBJECT_CREATE )
 				{
-					delete(p->asShapes());
-				}
-
-				p->Set_Value(DATAOBJECT_NOTSET);
-			}
-
-			//---------------------------------------------
-			if( p->is_Output() )
-			{
-				if( p->is_DataObject()
-				&&  p->asDataObject() != DATAOBJECT_NOTSET
-				&&  p->asDataObject() != DATAOBJECT_CREATE )
-				{
-					CSG_Data_Object	*pObject	= p->asDataObject();
-
-					if( m_pManager && !m_pManager->Exists(pObject) )
+					if( pObject->Get_ObjectType() == DATAOBJECT_TYPE_Shapes
+					&&  p->asShapes()->Get_Type() == SHAPE_TYPE_Undefined
+					&&  (m_pManager == &SG_Get_Data_Manager() || !SG_Get_Data_Manager().Exists(pObject)) )
 					{
-						m_pManager->Add(pObject);
+						if( m_pManager && !m_pManager->Delete(pObject) )
+						{
+							delete(pObject);
+						}
+
+						p->Set_Value(DATAOBJECT_NOTSET);
 					}
-
-					SG_UI_DataObject_Update(pObject, SG_UI_DATAOBJECT_UPDATE_ONLY, NULL);
-				}
-				else if( p->is_DataObject_List() )
-				{
-					for(int j=0; j<p->asList()->Get_Count(); j++)
+					else
 					{
-						CSG_Data_Object	*pObject	= p->asList()->asDataObject(j);
-
 						if( m_pManager && !m_pManager->Exists(pObject) )
 						{
 							m_pManager->Add(pObject);
@@ -1473,6 +1493,22 @@ bool CSG_Parameters::DataObjects_Synchronize(void)
 					}
 				}
 			}
+
+			//---------------------------------------------
+			else if( p->is_DataObject_List() )
+			{
+				for(int j=0; j<p->asList()->Get_Count(); j++)
+				{
+					CSG_Data_Object	*pObject	= p->asList()->asDataObject(j);
+
+					if( m_pManager && !m_pManager->Exists(pObject) )
+					{
+						m_pManager->Add(pObject);
+					}
+
+					SG_UI_DataObject_Update(pObject, SG_UI_DATAOBJECT_UPDATE_ONLY, NULL);
+				}
+			}
 		}
 	}
 
@@ -1727,7 +1763,7 @@ bool CSG_Parameters::Set_History(CSG_MetaData &MetaData, bool bOptions, bool bDa
 
 						pEntry	= pList->Add_Child(*pList, false);
 
-						pEntry->Set_Name(pObject->Get_Name());
+						pEntry->Set_Name("INPUT");
 						
 						if( !SG_Get_History_Ignore_Lists() && pObject->Get_History().Get_Children_Count() > 0 )
 						{
