@@ -1333,6 +1333,8 @@ public:
 	bool						Set_Value				(int               Value);
 	bool						Set_Value				(double            Value);
 	bool						Set_Value				(const CSG_String &Value);
+	bool						Set_Value				(const char       *Value);
+	bool						Set_Value				(const wchar_t    *Value);
 	bool						Set_Value				(void             *Value);
 	bool						Set_Value				(CSG_Parameter    *Value);
 
@@ -1423,7 +1425,7 @@ private:
 class SAGA_API_DLL_EXPORT CSG_Parameters
 {
 	friend class CSG_Parameter;
-	friend class CSG_Module;
+	friend class CSG_Tool;
 
 public:
 	CSG_Parameters(void);
@@ -1454,6 +1456,10 @@ public:
 	void						Set_Description			(const CSG_String &String);
 	const CSG_String &			Get_Description			(void)	const	{	return( m_Description );	}
 
+	void						Add_Reference			(const CSG_String &Authors, const CSG_String &Year, const CSG_String &Title, const CSG_String &Where, const SG_Char *Link = NULL, const SG_Char *Link_Text = NULL);
+	void						Add_Reference			(const CSG_String &Link, const SG_Char *Link_Text = NULL);
+	const CSG_Strings &			Get_References			(void)	const	{	return( m_References );		}
+
 	void						Set_Enabled				(bool bEnabled = true);
 	void						Set_Enabled				(const CSG_String &Identifier, bool bEnabled = true);
 
@@ -1579,6 +1585,8 @@ private:
 
 	CSG_String					m_Identifier, m_Name, m_Description;
 
+	CSG_Strings					m_References;
+
 	int							m_nParameters;
 
 	CSG_Parameter				**m_Parameters, *m_pGrid_System;
