@@ -81,8 +81,8 @@
 #include "grid_pyramid.h"
 #include "mat_tools.h"
 #include "metadata.h"
-#include "module.h"
-#include "module_library.h"
+#include "tool.h"
+#include "tool_library.h"
 #include "parameters.h"
 #include "pointcloud.h"
 #include "saga_api.h"
@@ -115,7 +115,7 @@
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#include "module_library.h"
+#include "tool_library.h"
 #include "data_manager.h"
 
 
@@ -126,10 +126,10 @@
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#define SAGA_MAJOR_VERSION		2
-#define SAGA_MINOR_VERSION		3
-#define SAGA_RELEASE_NUMBER		1
-#define SAGA_VERSION			SG_T("2.3.1")
+#define SAGA_MAJOR_VERSION		3
+#define SAGA_MINOR_VERSION		0
+#define SAGA_RELEASE_NUMBER		0
+#define SAGA_VERSION			SG_T("3.0.0")
 
 
 ///////////////////////////////////////////////////////////
