@@ -65,7 +65,7 @@
 //---------------------------------------------------------
 #include "shapes.h"
 #include "pointcloud.h"
-#include "module_library.h"
+#include "tool_library.h"
 
 
 ///////////////////////////////////////////////////////////
@@ -246,9 +246,9 @@ bool CSG_Shapes::Create(const CSG_String &File_Name)
 		s	= s.AfterFirst(':');	CSG_String	DBName(s.BeforeFirst(':'));
 		s	= s.AfterFirst(':');	CSG_String	Table (s.BeforeFirst(':'));
 
-		CSG_Module	*pModule	= SG_Get_Module_Library_Manager().Get_Module("db_pgsql", 0);	// CGet_Connections
+		CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Get_Tool("db_pgsql", 0);	// CGet_Connections
 
-		if(	pModule != NULL )
+		if(	pTool != NULL )
 		{
 			SG_UI_ProgressAndMsg_Lock(true);
 
@@ -256,9 +256,9 @@ bool CSG_Shapes::Create(const CSG_String &File_Name)
 			CSG_Table	Connections;
 			CSG_String	Connection	= DBName + " [" + Host + ":" + Port + "]";
 
-			pModule->Settings_Push();
+			pTool->Settings_Push();
 
-			if( pModule->On_Before_Execution() && SG_MODULE_PARAMETER_SET("CONNECTIONS", &Connections) && pModule->Execute() )	// CGet_Connections
+			if( pTool->On_Before_Execution() && SG_TOOL_PARAMETER_SET("CONNECTIONS", &Connections) && pTool->Execute() )	// CGet_Connections
 			{
 				for(int i=0; !bResult && i<Connections.Get_Count(); i++)
 				{
@@ -269,20 +269,20 @@ bool CSG_Shapes::Create(const CSG_String &File_Name)
 				}
 			}
 
-			pModule->Settings_Pop();
+			pTool->Settings_Pop();
 
 			//---------------------------------------------
-			if( bResult && (bResult = (pModule = SG_Get_Module_Library_Manager().Get_Module("db_pgsql", 20)) != NULL) == true )	// CPGIS_Shapes_Load
+			if( bResult && (bResult = (pTool = SG_Get_Tool_Library_Manager().Get_Tool("db_pgsql", 20)) != NULL) == true )	// CPGIS_Shapes_Load
 			{
-				pModule->Settings_Push();
+				pTool->Settings_Push();
 
-				bResult	= pModule->On_Before_Execution()
-					&& SG_MODULE_PARAMETER_SET("CONNECTION", Connection)
-					&& SG_MODULE_PARAMETER_SET("TABLES"    , Table)
-					&& SG_MODULE_PARAMETER_SET("SHAPES"    , this)
-					&& pModule->Execute();
+				bResult	= pTool->On_Before_Execution()
+					&& SG_TOOL_PARAMETER_SET("CONNECTION", Connection)
+					&& SG_TOOL_PARAMETER_SET("TABLES"    , Table)
+					&& SG_TOOL_PARAMETER_SET("SHAPES"    , this)
+					&& pTool->Execute();
 
-				pModule->Settings_Pop();
+				pTool->Settings_Pop();
 			}
 
 			SG_UI_ProgressAndMsg_Lock(false);
