@@ -699,6 +699,8 @@ protected:
 
 
 	virtual bool					On_Update				(void);
+	virtual bool					On_Reload				(void);
+	virtual bool					On_Delete				(void);
 
 	virtual void					_On_Construction		(void);
 
