@@ -148,8 +148,8 @@ public:
 	bool						is_NoData		(int              iField)	const;
 	bool						is_NoData		(const CSG_String &Field)	const;
 
-	const SG_Char *				asString		(int              iField, int Decimals = -1)	const;
-	const SG_Char *				asString		(const CSG_String &Field, int Decimals = -1)	const;
+	const SG_Char *				asString		(int              iField, int Decimals = 0)	const;
+	const SG_Char *				asString		(const CSG_String &Field, int Decimals = 0)	const;
 
 	SG_Char						asChar			(int              iField)	const	{	return( (SG_Char)asInt   (iField) );	}
 	SG_Char						asChar			(const CSG_String &Field)	const	{	return( (SG_Char)asInt   ( Field) );	}
@@ -270,6 +270,7 @@ public:
 	double							Get_Mean			(int iField)	const	{	return( _Stats_Update(iField) ? m_Field_Stats[iField]->Get_Mean()     : 0.0 );	}
 	double							Get_StdDev			(int iField)	const	{	return( _Stats_Update(iField) ? m_Field_Stats[iField]->Get_StdDev()   : 0.0 );	}
 	double							Get_Variance		(int iField)	const	{	return( _Stats_Update(iField) ? m_Field_Stats[iField]->Get_Variance() : 0.0 );	}
+	const CSG_Simple_Statistics &	Get_Statistics		(int iField)	const	{	_Stats_Update(iField); return( *m_Field_Stats[iField] );	}
 
 	//-----------------------------------------------------
 	virtual CSG_Table_Record *		Add_Record			(             CSG_Table_Record *pCopy = NULL);
@@ -358,6 +359,9 @@ protected:
 	bool							_Stats_Invalidate	(int iField)	const;
 	virtual bool					_Stats_Update		(int iField)	const;
 
+	virtual bool					On_Reload			(void);
+	virtual bool					On_Delete			(void);
+
 
 private:
 
@@ -373,7 +377,8 @@ private:
 	bool							_Inc_Array			(void);
 	bool							_Dec_Array			(void);
 
-	int								_Load_Text_Trim		(CSG_String &Text, const SG_Char Separator);
+	size_t							_Load_Text_Trim		(      CSG_String &Text, const SG_Char Separator);
+	size_t							_Load_Text_EndQuote	(const CSG_String &Text, const SG_Char Separator);
 
 	bool							_Load_Text			(const CSG_String &File_Name, bool bHeadline, const SG_Char Separator);
 	bool							_Save_Text			(const CSG_String &File_Name, bool bHeadline, const SG_Char Separator);
