@@ -67,6 +67,25 @@
 #include "table_dbase.h"
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_Table::On_Reload(void)
+{
+	return( Create(Get_File_Name(false)) );
+}
+
+//---------------------------------------------------------
+bool CSG_Table::On_Delete(void)
+{
+	return( SG_File_Delete(Get_File_Name(false)) );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
@@ -217,17 +236,17 @@ bool CSG_Table::Save(const CSG_String &File_Name, int Format, SG_Char Separator)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-int CSG_Table::_Load_Text_Trim(CSG_String &String, const SG_Char Separator)
+size_t CSG_Table::_Load_Text_Trim(CSG_String &s, const SG_Char Separator)
 {
-	for(size_t i=0; i<String.Length(); i++)
+	for(size_t i=0; i<s.Length(); i++)
 	{
-		SG_Char	c	= String[i];
+		SG_Char	c	= s[i];
 
 		if( c == Separator || (c != ' ' && c != '\t' && c != '\n' && c != '\v' && c != '\f' && c != '\r') )
 		{
 			if( i > 0 )
 			{
-				String	= String.Right(String.Length() - i);
+				s	= s.Right(s.Length() - i);
 			}
 
 			return( i );
@@ -237,6 +256,41 @@ int CSG_Table::_Load_Text_Trim(CSG_String &String, const SG_Char Separator)
 	return( 0 );
 }
 
+//---------------------------------------------------------
+size_t	CSG_Table::_Load_Text_EndQuote(const CSG_String &s, const SG_Char Separator)
+{
+	if( s.Length() > 1 && s[0] == '\"' )
+	{
+		bool	bInQuotes	= true;
+
+		for(size_t i=1; i<s.Length(); i++)
+		{
+			if( bInQuotes )
+			{
+				if( s[i] == '\"' )
+				{
+					bInQuotes	= false;
+				}
+			}
+			else if( s[i] == '\"' )
+			{
+				bInQuotes	= true;
+			}
+			else if( s[i] == Separator )
+			{
+				return( i );
+			}
+		}
+
+		if( s[s.Length() - 1] == '\"' )
+		{
+			return( s.Length() );
+		}
+	}
+
+	return( 0 );
+}
+
 //---------------------------------------------------------
 bool CSG_Table::_Load_Text(const CSG_String &File_Name, bool bHeadline, const SG_Char Separator)
 {
@@ -308,10 +362,12 @@ bool CSG_Table::_Load_Text(const CSG_String &File_Name, bool bHeadline, const SG
 
 		for(iField=0; iField<Table.Get_Field_Count() && !sLine.is_Empty(); iField++)
 		{
-			if( sLine[0] == '\"' )	// value in quotas
+			size_t	Position	= _Load_Text_EndQuote(sLine, Separator);
+
+			if( Position > 0 )	// value in quotas !!!
 			{
-				sField	= sLine.AfterFirst('\"').BeforeFirst('\"');
-				sLine	= sLine.AfterFirst('\"').AfterFirst ('\"');
+				sField	= sLine.Mid(1, Position - 2);
+				sLine	= sLine.Right(sLine.Length() - Position);
 
 				Type[iField]	= SG_DATATYPE_String;
 			}
@@ -382,48 +438,51 @@ bool CSG_Table::_Load_Text(const CSG_String &File_Name, bool bHeadline, const SG
 //---------------------------------------------------------
 bool CSG_Table::_Save_Text(const CSG_String &File_Name, bool bHeadline, const SG_Char Separator)
 {
-	int			iField, iRecord;
 	CSG_File	Stream;
 
-	if( Get_Field_Count() > 0 )
+	if( Get_Field_Count() <= 0 || Stream.Open(File_Name, SG_FILE_W, false) == false )
 	{
-		if( Stream.Open(File_Name, SG_FILE_W, false) )
+		return( false );
+	}
+
+	//-----------------------------------------------------
+	{
+		for(int iField=0; iField<Get_Field_Count(); iField++)
 		{
-			for(iField=0; iField<Get_Field_Count(); iField++)
-			{
-				Stream.Printf(SG_T("%s%c"), Get_Field_Name(iField), iField < Get_Field_Count() - 1 ? Separator : '\n');
-			}
-
-			for(iRecord=0; iRecord<Get_Record_Count() && SG_UI_Process_Set_Progress(iRecord, Get_Record_Count()); iRecord++)
-			{
-				for(iField=0; iField<Get_Field_Count(); iField++)
-				{
-					if( !Get_Record(iRecord)->is_NoData(iField) )
-					{
-						switch( Get_Field_Type(iField) )
-						{
-						case SG_DATATYPE_String:
-						case SG_DATATYPE_Date:
-							Stream.Printf(SG_T("\"%s\""), Get_Record(iRecord)->asString(iField));
-							break;
-
-						default:
-							Stream.Printf(SG_T("%s")    , Get_Record(iRecord)->asString(iField));
-							break;
-						}
-					}
-
-					Stream.Printf(SG_T("%c"), iField < Get_Field_Count() - 1 ? Separator : '\n');
-				}
-			}
-
-			SG_UI_Process_Set_Ready();
-
-			return( true );
+			Stream.Printf("%s%c", Get_Field_Name(iField), iField < Get_Field_Count() - 1 ? Separator : '\n');
 		}
 	}
 
-	return( false );
+	//-----------------------------------------------------
+	for(int iRecord=0; iRecord<Get_Record_Count() && SG_UI_Process_Set_Progress(iRecord, Get_Record_Count()); iRecord++)
+	{
+		CSG_Table_Record	*pRecord	= Get_Record_byIndex(iRecord);
+
+		for(int iField=0; iField<Get_Field_Count(); iField++)
+		{
+			if( !pRecord->is_NoData(iField) )
+			{
+				switch( Get_Field_Type(iField) )
+				{
+				case SG_DATATYPE_String:
+				case SG_DATATYPE_Date:
+					Stream.Printf("\"%s\"", pRecord->asString(iField));
+					break;
+
+				default:
+					Stream.Printf("%s"    , pRecord->asString(iField));
+					break;
+				}
+			}
+
+			Stream.Printf("%c", iField < Get_Field_Count() - 1 ? Separator : '\n');
+		}
+	}
+
+	//-----------------------------------------------------
+	SG_UI_Process_Set_Ready();
+
+	return( true );
 }
 
 
