@@ -140,13 +140,13 @@ wxString CMD_Get_Name(int Cmd_ID)
 	case ID_CMD_DB_TABLE_INFO:			return( _TL("Field Description") );
 	case ID_CMD_DB_TABLE_FROM_QUERY:	return( _TL("Query") );
 
-	case ID_CMD_MODULES_OPEN:			return( _TL("Load Tool Library") );
-	case ID_CMD_MODULES_SEARCH:			return( _TL("Find and Run Tool") );
-	case ID_CMD_MODULES_SAVE_DOCS:		return( _TL("Create Tool Description Files") );
-	case ID_CMD_MODULES_SAVE_SCRIPT:		return( _TL("Save to Script File") );
-	case ID_CMD_MODULES_SAVE_TO_CLIPBOARD:	return( _TL("Save to Clipboard") );
-	case ID_CMD_MODULES_CHAIN_RELOAD:	return( _TL("Reload") );
-	case ID_CMD_MODULES_CHAIN_EDIT:		return( _TL("Edit") );
+	case ID_CMD_TOOLS_OPEN:			return( _TL("Load Tool Library") );
+	case ID_CMD_TOOLS_SEARCH:			return( _TL("Find and Run Tool") );
+	case ID_CMD_TOOLS_SAVE_DOCS:		return( _TL("Create Tool Description Files") );
+	case ID_CMD_TOOLS_SAVE_SCRIPT:		return( _TL("Save to Script File") );
+	case ID_CMD_TOOLS_SAVE_TO_CLIPBOARD:	return( _TL("Save to Clipboard") );
+	case ID_CMD_TOOLS_CHAIN_RELOAD:	return( _TL("Reload") );
+	case ID_CMD_TOOLS_CHAIN_EDIT:		return( _TL("Edit") );
 
 	case ID_CMD_DATA_PROJECT_OPEN:		return( _TL("Load Project") );
 	case ID_CMD_DATA_PROJECT_OPEN_ADD:	return( _TL("Add Project") );
@@ -170,6 +170,8 @@ wxString CMD_Get_Name(int Cmd_ID)
 	case ID_CMD_DATA_SAVE:				return( _TL("Save") );
 	case ID_CMD_DATA_SAVEAS:			return( _TL("Save as...") );
 	case ID_CMD_DATA_SAVETODB:			return( _TL("Save to Database...") );
+	case ID_CMD_DATA_RELOAD:			return( _TL("Reload") );
+	case ID_CMD_DATA_DEL_FILES:			return( _TL("Delete Associated Files") );
 	case ID_CMD_DATA_PROJECTION:		return( _TL("Spatial Reference") );
 
 	case ID_CMD_GRIDS_OPEN:
@@ -367,8 +369,8 @@ int CMD_Get_ImageID(int Cmd_ID)
 	case ID_CMD_FRAME_HELP:				return( ID_IMG_TB_HELP );
 	case ID_CMD_DATA_OPEN:				return( ID_IMG_TB_OPEN );
 	case ID_CMD_DATA_PROJECT_SAVE:		return( ID_IMG_TB_SAVE );
-	case ID_CMD_MODULES_OPEN:			return( ID_IMG_TB_OPEN_MODULE );
-	case ID_CMD_MODULES_SEARCH:			return( ID_IMG_NB_WKSP_MODULES );
+	case ID_CMD_TOOLS_OPEN:			return( ID_IMG_TB_OPEN_TOOL );
+	case ID_CMD_TOOLS_SEARCH:			return( ID_IMG_NB_WKSP_TOOLS );
 	case ID_CMD_TABLES_OPEN:			return( ID_IMG_TB_OPEN_TABLE );
 	case ID_CMD_SHAPES_OPEN:			return( ID_IMG_TB_OPEN_SHAPES );
 	case ID_CMD_GRIDS_OPEN:				return( ID_IMG_TB_OPEN_GRID );
