@@ -113,7 +113,7 @@ enum ID_CONTROLS
 	ID_WND_PARM,
 
 	ID_WND_WKSP,
-	ID_WND_WKSP_MODULES,
+	ID_WND_WKSP_TOOLS,
 	ID_WND_WKSP_DATA,
 	ID_WND_WKSP_MAPS,
 
