@@ -92,7 +92,7 @@ enum ID_DIALOGS
 
 	ID_DLG_WKSP_OPEN,
 	ID_DLG_ALLFILES_OPEN,
-	ID_DLG_MODULES_OPEN,
+	ID_DLG_TOOLS_OPEN,
 	ID_DLG_PROJECT_OPEN,
 	ID_DLG_PROJECT_SAVE,
 	ID_DLG_TABLES_OPEN,
