@@ -101,7 +101,7 @@ enum ID_IMAGES
 	ID_IMG_NB_WKSP_DATA_BUTTONS,
 	ID_IMG_NB_WKSP_MAPS,
 	ID_IMG_NB_WKSP_MAPS_BUTTONS,
-	ID_IMG_NB_WKSP_MODULES,
+	ID_IMG_NB_WKSP_TOOLS,
 	ID_IMG_NB_WKSP_THUMBNAILS,
 	ID_IMG_NB_WKSP_TREEVIEW,
 	ID_IMG_SAGA_ICON_16,
@@ -176,7 +176,7 @@ enum ID_IMAGES
 	ID_IMG_TB_MAP_ZOOM_SELECTION,
 	ID_IMG_TB_OPEN,
 	ID_IMG_TB_OPEN_GRID,
-	ID_IMG_TB_OPEN_MODULE,
+	ID_IMG_TB_OPEN_TOOL,
 	ID_IMG_TB_OPEN_SHAPES,
 	ID_IMG_TB_OPEN_TABLE,
 	ID_IMG_TB_OPEN_TIN,
@@ -200,11 +200,11 @@ enum ID_IMAGES
 	ID_IMG_WKSP_MAP_MANAGER,
 	ID_IMG_WKSP_MAP_GRATICULE,
 	ID_IMG_WKSP_MAP_BASEMAP,
-	ID_IMG_WKSP_MODULE,
-	ID_IMG_WKSP_MODULE_CHAIN,
-	ID_IMG_WKSP_MODULE_LIBRARY,
-	ID_IMG_WKSP_MODULE_GROUP,
-	ID_IMG_WKSP_MODULE_MANAGER,
+	ID_IMG_WKSP_TOOL,
+	ID_IMG_WKSP_TOOL_CHAIN,
+	ID_IMG_WKSP_TOOL_LIBRARY,
+	ID_IMG_WKSP_TOOL_GROUP,
+	ID_IMG_WKSP_TOOL_MANAGER,
 	ID_IMG_WKSP_NOITEMS,
 	ID_IMG_WKSP_DB_SOURCES,
 	ID_IMG_WKSP_DB_SOURCE_ON,
