@@ -153,7 +153,7 @@ private:
 
 	bool						m_bSelOnly, m_bEditing;
 
-	int							m_Scroll_Start, m_Scroll_Range, m_Cursor;
+	int							m_Scroll_Start, m_Scroll_Range, m_Cursor, m_Decimals;
 
 	class CSG_Table				*m_pTable;
 
@@ -167,6 +167,7 @@ private:
 	int							_Get_Record_Count	(void);
 	CSG_Table_Record *			_Get_Record			(int iRow);
 	bool						_Set_Record			(int iRow);
+	wxString					_Get_Value			(CSG_Table_Record *pRecord, int iField);
 
 	int							_Get_Scroll_Start	(int Position);
 	bool						_Set_Scroll_Start	(int Position, bool bEnforceUpdate = true);
