@@ -359,34 +359,34 @@ int CWKSP_Layer::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter
 {
 	if( Flags & PARAMETER_CHECK_ENABLE )
 	{
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), SG_T("LEGEND_SHOW"))
-		||	!SG_STR_CMP(pParameter->Get_Identifier(), SG_T("COLORS_TYPE")) )
+		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "LEGEND_SHOW")
+		||	!SG_STR_CMP(pParameter->Get_Identifier(), "COLORS_TYPE") )
 		{
-			pParameters->Get_Parameter("LEGEND_STYLE")->Set_Enabled(
+			pParameters->Set_Enabled("LEGEND_STYLE",
 				pParameters->Get_Parameter("LEGEND_SHOW")->asBool()
 			&&	pParameters->Get_Parameter("COLORS_TYPE")->asInt() == CLASSIFY_GRADUATED
 			);
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), SG_T("SHOW_ALWAYS")) )
+		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "SHOW_ALWAYS") )
 		{
-			pParameters->Get_Parameter("SHOW_RANGE")->Set_Enabled(pParameter->asBool() == false);
+			pParameters->Set_Enabled("SHOW_RANGE", pParameter->asBool() == false);
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), SG_T("COLORS_TYPE")) )
+		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "COLORS_TYPE") )
 		{
 			int		Value	= pParameter->asInt();
 
-			pParameters->Get_Parameter("NODE_UNISYMBOL")->Set_Enabled(Value == CLASSIFY_UNIQUE);
-			pParameters->Get_Parameter("NODE_LUT"      )->Set_Enabled(Value == CLASSIFY_LUT);
-			pParameters->Get_Parameter("NODE_METRIC"   )->Set_Enabled(Value != CLASSIFY_UNIQUE && Value != CLASSIFY_LUT && Value != CLASSIFY_RGB);
+			pParameters->Set_Enabled("NODE_UNISYMBOL", Value == CLASSIFY_UNIQUE);
+			pParameters->Set_Enabled("NODE_LUT"      , Value == CLASSIFY_LUT);
+			pParameters->Set_Enabled("NODE_METRIC"   , Value != CLASSIFY_UNIQUE && Value != CLASSIFY_LUT && Value != CLASSIFY_RGB);
 
-			pParameters->Get_Parameter("METRIC_COLORS" )->Set_Enabled(Value == CLASSIFY_METRIC || Value == CLASSIFY_GRADUATED);
+			pParameters->Set_Enabled("METRIC_COLORS" , Value == CLASSIFY_METRIC || Value == CLASSIFY_GRADUATED);
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), SG_T("METRIC_SCALE_MODE")) )
+		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "METRIC_SCALE_MODE") )
 		{
-			pParameters->Get_Parameter("METRIC_SCALE_LOG")->Set_Enabled(pParameter->asInt() != 0);
+			pParameters->Set_Enabled("METRIC_SCALE_LOG", pParameter->asInt() != 0);
 		}
 	}
 
@@ -517,23 +517,23 @@ CSG_Rect CWKSP_Layer::Get_Extent(void)
 //---------------------------------------------------------
 void CWKSP_Layer::_Set_Projection(void)
 {
-	CSG_Module	*pModule	= SG_Get_Module_Library_Manager().Get_Module(SG_T("pj_proj4"), 15);	// CCRS_Picker
+	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Get_Tool(SG_T("pj_proj4"), 15);	// CCRS_Picker
 
-	if(	pModule && Get_Object() )
+	if(	pTool && Get_Object() )
 	{
-		CSG_Parameters	P; P.Assign(pModule->Get_Parameters());
+		CSG_Parameters	P; P.Assign(pTool->Get_Parameters());
 
-		if( pModule->Get_Parameters()->Set_Parameter("CRS_PROJ4", Get_Object()->Get_Projection().Get_Proj4())
-		&&	pModule->On_Before_Execution() && DLG_Parameters(pModule->Get_Parameters())
-		&&  pModule->Execute() )
+		if( pTool->Get_Parameters()->Set_Parameter("CRS_PROJ4", Get_Object()->Get_Projection().Get_Proj4())
+		&&	pTool->On_Before_Execution() && DLG_Parameters(pTool->Get_Parameters())
+		&&  pTool->Execute() )
 		{
-			Get_Object()->Get_Projection().Create(pModule->Get_Parameters()->Get_Parameter("CRS_PROJ4")->asString(), SG_PROJ_FMT_Proj4);
+			Get_Object()->Get_Projection().Create(pTool->Get_Parameters()->Get_Parameter("CRS_PROJ4")->asString(), SG_PROJ_FMT_Proj4);
 			Get_Object()->Set_Modified();
 
 			DataObject_Changed();
 		}
 
-		pModule->Get_Parameters()->Assign_Values(&P);
+		pTool->Get_Parameters()->Assign_Values(&P);
 	}
 }
 
