@@ -437,32 +437,32 @@ bool CWKSP_Map_Graticule::Get_Graticule(const CSG_Rect &Extent)
 	m_Graticule  .Create(SHAPE_TYPE_Line );
 	m_Coordinates.Create(SHAPE_TYPE_Point);
 
-	CSG_Module	*pModule	= SG_Get_Module_Library_Manager().Get_Module("pj_proj4", 14);
+	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Get_Tool("pj_proj4", 14);
 
-	if(	pModule && Get_Map()->Get_Projection().is_Okay() )
+	if(	pTool && Get_Map()->Get_Projection().is_Okay() )
 	{
 		SG_UI_Msg_Lock     (true);
 		SG_UI_Progress_Lock(true);
 
-		pModule->Settings_Push();
+		pTool->Settings_Push();
 
-		if( pModule->Set_Parameter("XMIN"      , Extent.Get_XMin())
-		&&  pModule->Set_Parameter("XMAX"      , Extent.Get_XMax())
-		&&  pModule->Set_Parameter("YMIN"      , Extent.Get_YMin())
-		&&  pModule->Set_Parameter("YMAX"      , Extent.Get_YMax())
-		&&  pModule->Set_Parameter("INTERVAL"  , m_Parameters("INTERVAL"))
-		&&  pModule->Set_Parameter("FIXED"     , m_Parameters("FIXED"))
-		&&  pModule->Set_Parameter("FITTED"    , m_Parameters("FITTED"))
-		&&  pModule->Set_Parameter("RESOLUTION", m_Parameters("RESOLUTION"))
-		&&  pModule->Set_Parameter("GRATICULE" , &m_Graticule)
-		&&  pModule->Set_Parameter("COORDS"    , &m_Coordinates)
-		&&  pModule->Set_Parameter("CRS_PROJ4" , Get_Map()->Get_Projection().Get_Proj4())
-		&&  pModule->On_Before_Execution() && pModule->Execute() )
+		if( pTool->Set_Parameter("XMIN"      , Extent.Get_XMin())
+		&&  pTool->Set_Parameter("XMAX"      , Extent.Get_XMax())
+		&&  pTool->Set_Parameter("YMIN"      , Extent.Get_YMin())
+		&&  pTool->Set_Parameter("YMAX"      , Extent.Get_YMax())
+		&&  pTool->Set_Parameter("INTERVAL"  , m_Parameters("INTERVAL"))
+		&&  pTool->Set_Parameter("FIXED"     , m_Parameters("FIXED"))
+		&&  pTool->Set_Parameter("FITTED"    , m_Parameters("FITTED"))
+		&&  pTool->Set_Parameter("RESOLUTION", m_Parameters("RESOLUTION"))
+		&&  pTool->Set_Parameter("GRATICULE" , &m_Graticule)
+		&&  pTool->Set_Parameter("COORDS"    , &m_Coordinates)
+		&&  pTool->Set_Parameter("CRS_PROJ4" , Get_Map()->Get_Projection().Get_Proj4())
+		&&  pTool->On_Before_Execution() && pTool->Execute() )
 		{
 			bResult	= true;
 		}
 
-		pModule->Settings_Pop();
+		pTool->Settings_Pop();
 
 		SG_UI_Msg_Lock     (false);
 		SG_UI_Progress_Lock(false);
