@@ -69,6 +69,8 @@
 
 #include "wksp_layer_classify.h"
 
+#include "wksp_data_manager.h"
+
 #include "wksp_shapes.h"
 #include "wksp_table.h"
 
@@ -154,6 +156,7 @@ wxString CWKSP_Shapes::Get_Description(void)
 	DESC_ADD_STR(_TL("Type"            ), SG_Get_ShapeType_Name(Get_Shapes()->Get_Type()).c_str());
 	DESC_ADD_STR(_TL("Vertex Type"     ), Get_Shapes()->Get_Vertex_Type() == 0 ? _TL("X, Y") : Get_Shapes()->Get_Vertex_Type() == 1 ? _TL("X, Y, Z") : _TL("X, Y, Z, M"));
 	DESC_ADD_INT(_TL("Number of Shapes"), Get_Shapes()->Get_Count());
+	DESC_ADD_INT(_TL("Selected"        ), Get_Shapes()->Get_Selection_Count());
 
 	s	+= wxT("</table>");
 
@@ -174,22 +177,29 @@ wxMenu * CWKSP_Shapes::Get_Menu(void)
 
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_WKSP_ITEM_CLOSE);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_SHOW);
+
 	pMenu->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_SAVE);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_SAVEAS);
+
 	if( PGSQL_has_Connections() )
-	{
 		CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_SAVETODB);
-	}
+
+	if( m_pObject->is_File_Native() && m_pObject->is_Modified() )
+		CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_RELOAD);
+
+	if( m_pObject->is_File_Native() )
+		CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_DEL_FILES);
+
 	pMenu->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_PROJECTION);
+
 	pMenu->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu,  true, ID_CMD_SHAPES_HISTOGRAM);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_SET_LUT);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_WKSP_ITEM_SETTINGS_COPY);
 
 	pMenu->AppendSeparator();
-
 	wxMenu	*pTable	= new wxMenu(_TL("Attributes"));
 	CMD_Menu_Add_Item(pTable,  true, ID_CMD_TABLES_SHOW);
 	CMD_Menu_Add_Item(pTable,  true, ID_CMD_TABLES_DIAGRAM);
@@ -343,41 +353,46 @@ void CWKSP_Shapes::On_Create_Parameters(void)
 	//-----------------------------------------------------
 	// Classification...
 
-	AttributeList_Add(
-		m_Parameters("NODE_LUT")		, "LUT_ATTRIB"				, _TL("Attribute"),
-		_TL("")
+	AttributeList_Add(m_Parameters("NODE_LUT"   ), "LUT_ATTRIB"   , _TL("Attribute"), _TL(""));
+	AttributeList_Add(m_Parameters("NODE_METRIC"), "METRIC_ATTRIB", _TL("Attribute"), _TL(""));
+	AttributeList_Add(m_Parameters("NODE_METRIC"), "METRIC_NORMAL", _TL("Normalize"), _TL(""));
+
+	m_Parameters.Add_Bool(
+		m_Parameters("NODE_COLORS"), "NODATA_SHOW" , _TL("Show No-Data"), _TL(""), true
 	);
 
-	AttributeList_Add(
-		m_Parameters("NODE_METRIC")		, "METRIC_ATTRIB"			, _TL("Attribute"),
-		_TL("")
+	m_Parameters.Add_Color(
+		m_Parameters("NODATA_SHOW"), "NODATA_COLOR", _TL("Color"), _TL(""), SG_COLOR_GREY_LIGHT
 	);
 
 	//-----------------------------------------------------
 	// Display...
 
 	m_Parameters.Add_Parameters(
-		m_Parameters("NODE_DISPLAY")	, "DISPLAY_CHART"			, _TL("Chart"),
-		_TL("")
+		m_Parameters("NODE_DISPLAY"), "DISPLAY_CHART", _TL("Chart"), _TL("")
 	);
 
+	m_Parameters.Add_Node(NULL, "NODE_TABLE", _TL("Attributes Table"), _TL(""));
+	m_Parameters.Add_Parameter(g_pData->Get_Parameter("TABLE_FLT_STYLE"   ));
+	m_Parameters.Add_Parameter(g_pData->Get_Parameter("TABLE_FLT_DECIMALS"));
+
 	//-----------------------------------------------------
 	// Label...
 
 	AttributeList_Add(
-		m_Parameters("NODE_LABEL")		, "LABEL_ATTRIB"			, _TL("Attribute"),
+		m_Parameters("NODE_LABEL"  ), "LABEL_ATTRIB"     , _TL("Attribute"),
 		_TL("")
 	);
 
 	m_Parameters.Add_Font(
-		m_Parameters("LABEL_ATTRIB")	, "LABEL_ATTRIB_FONT"		, _TL("Font"),
+		m_Parameters("LABEL_ATTRIB"), "LABEL_ATTRIB_FONT", _TL("Font"),
 		_TL("")
 	);
 
 	m_Parameters.Add_Choice(
-		m_Parameters("LABEL_ATTRIB")	, "LABEL_ATTRIB_PREC"		, _TL("Numerical Precision"),
+		m_Parameters("LABEL_ATTRIB"), "LABEL_ATTRIB_PREC", _TL("Numerical Precision"),
 		_TL(""),
-		CSG_String::Format(SG_T("%s|%s|%s|"),
+		CSG_String::Format("%s|%s|%s|",
 			_TL("fit to value"),
 			_TL("standard"),
 			SG_T("0|0.1|0.12|0.123|0.1234|0.12345|0.1234567|0.12345678|0.123456789|0.1234567890|0.12345678901|0.123456789012|0.1234567890123|0.12345678901234|0.123456789012345|0.1234567890123456|0.12345678901234567|0.123456789012345678|0.1234567890123456789|0.12345678901234567890")
@@ -385,18 +400,18 @@ void CWKSP_Shapes::On_Create_Parameters(void)
 	);
 
 	m_Parameters.Add_Choice(
-		m_Parameters("LABEL_ATTRIB")	, "LABEL_ATTRIB_SIZE_TYPE"	, _TL("Size relates to..."),
+		m_Parameters("LABEL_ATTRIB"), "LABEL_ATTRIB_SIZE_TYPE", _TL("Size relates to..."),
 		_TL(""),
-		CSG_String::Format(SG_T("%s|%s|"),
+		CSG_String::Format("%s|%s|",
 			_TL("Screen"),
 			_TL("Map Units")
 		), 0
 	);
 
 	m_Parameters.Add_Choice(
-		m_Parameters("LABEL_ATTRIB")	, "LABEL_ATTRIB_EFFECT"		, _TL("Boundary Effect"),
+		m_Parameters("LABEL_ATTRIB"), "LABEL_ATTRIB_EFFECT", _TL("Boundary Effect"),
 		_TL(""),
-		CSG_String::Format(SG_T("%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|"),
+		CSG_String::Format("%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|",
 			_TL("none"),
 			_TL("full frame"),
 			_TL("top"),
@@ -410,57 +425,57 @@ void CWKSP_Shapes::On_Create_Parameters(void)
 		), 1
 	);
 
-	m_Parameters.Add_Value(
-		m_Parameters("LABEL_ATTRIB_EFFECT"), "LABEL_ATTRIB_EFFECT_COLOR"	, _TL("Color"),
+	m_Parameters.Add_Color(
+		m_Parameters("LABEL_ATTRIB_EFFECT" ), "LABEL_ATTRIB_EFFECT_COLOR", _TL("Color"),
 		_TL(""),
-		PARAMETER_TYPE_Color, SG_GET_RGB(255, 255, 255)
+		SG_GET_RGB(255, 255, 255)
 	);
 
-	m_Parameters.Add_Value(
-		m_Parameters("LABEL_ATTRIB_EFFECT"), "LABEL_ATTRIB_EFFECT_SIZE"		, _TL("Size"),
+	m_Parameters.Add_Int(
+		m_Parameters("LABEL_ATTRIB_EFFECT" ), "LABEL_ATTRIB_EFFECT_SIZE" , _TL("Size"),
 		_TL(""),
-		PARAMETER_TYPE_Int, 1, 1, true
+		1, 1, true
 	);
 
 	AttributeList_Add(
-		m_Parameters("LABEL_ATTRIB")	, "LABEL_ATTRIB_SIZE_BY"	, _TL("Size by Attribute"),
+		m_Parameters("LABEL_ATTRIB"        ), "LABEL_ATTRIB_SIZE_BY"     , _TL("Size by Attribute"),
 		_TL("")
 	);
 
-	m_Parameters.Add_Value(
-		m_Parameters("LABEL_ATTRIB_SIZE_BY"), "LABEL_ATTRIB_SIZE"	, _TL("Default Size"),
+	m_Parameters.Add_Double(
+		m_Parameters("LABEL_ATTRIB_SIZE_BY"), "LABEL_ATTRIB_SIZE"        , _TL("Default Size"),
 		_TL(""),
-		PARAMETER_TYPE_Double, 100.0, 0.0, true
+		100.0, 0.0, true
 	);
 
 	//-----------------------------------------------------
 	// Selection...
 
-	m_Parameters.Add_Value(
-		m_Parameters("NODE_SELECTION")	, "SEL_COLOR"				, _TL("Color"),
+	m_Parameters.Add_Color(
+		m_Parameters("NODE_SELECTION"), "SEL_COLOR"     , _TL("Color"),
 		_TL(""),
-		PARAMETER_TYPE_Color, SG_GET_RGB(255, 0, 0)
+		SG_GET_RGB(255, 0, 0)
 	);
 
 	//-----------------------------------------------------
 	// Edit...
 
-	m_Parameters.Add_Value(
-		m_Parameters("NODE_EDIT")		, "EDIT_COLOR"				, _TL("Color"),
+	m_Parameters.Add_Color(
+		m_Parameters("NODE_EDIT"     ), "EDIT_COLOR"    , _TL("Color"),
 		_TL(""),
-		PARAMETER_TYPE_Color, SG_GET_RGB(0, 0, 0)
+		SG_GET_RGB(0, 0, 0)
 	);
 
 	m_Parameters.Add_Shapes_List(
-		m_Parameters("NODE_EDIT")		, "EDIT_SNAP_LIST"			, _TL("Snap to..."),
+		m_Parameters("NODE_EDIT"     ), "EDIT_SNAP_LIST", _TL("Snap to..."),
 		_TL(""),
 		PARAMETER_INPUT
 	)->asShapesList()->Add_Item(m_pObject);
 
-	m_Parameters.Add_Value(
-		m_Parameters("EDIT_SNAP_LIST")	, "EDIT_SNAP_DIST"			, _TL("Snap Distance"),
+	m_Parameters.Add_Int(
+		m_Parameters("EDIT_SNAP_LIST"), "EDIT_SNAP_DIST", _TL("Snap Distance"),
 		_TL("snap distance in screen units (pixels)"),
-		PARAMETER_TYPE_Int, 10, 0, true
+		10, 0, true
 	);
 
 	m_Parameters("LUT")->asTable()->Set_Field_Type(LUT_MIN, SG_DATATYPE_String);
@@ -481,6 +496,7 @@ void CWKSP_Shapes::On_DataObject_Changed(void)
 
 	AttributeList_Set(m_Parameters("LUT_ATTRIB"          ), false);
 	AttributeList_Set(m_Parameters("METRIC_ATTRIB"       ), false);
+	AttributeList_Set(m_Parameters("METRIC_NORMAL"       ), true );
 	AttributeList_Set(m_Parameters("LABEL_ATTRIB"        ), true );
 	AttributeList_Set(m_Parameters("LABEL_ATTRIB_SIZE_BY"), true );
 
@@ -494,40 +510,49 @@ void CWKSP_Shapes::On_Parameters_Changed(void)
 {
 	CWKSP_Layer::On_Parameters_Changed();
 
-	m_Def_Color	= Get_Color_asWX(m_Parameters("UNISYMBOL_COLOR")->asColor());
-
 	//-----------------------------------------------------
 	switch( m_Parameters("COLORS_TYPE")->asInt() )
 	{
-	default:
-	case 0:	m_iColor	= -1;										break;	// CLASSIFY_UNIQUE
-	case 1:	m_iColor	= m_Parameters("LUT_ATTRIB"   )->asInt();	break;	// CLASSIFY_LUT
-	case 2:	m_iColor	= m_Parameters("METRIC_ATTRIB")->asInt();	break;	// CLASSIFY_METRIC
-	case 3:	m_iColor	= m_Parameters("METRIC_ATTRIB")->asInt();	break;	// CLASSIFY_GRADUATED
+	default:	// CLASSIFY_UNIQUE
+		m_fValue	= -1;
+		m_fNormal	= -1;
+		break;
+
+	case  1:	// CLASSIFY_LUT
+		m_fValue	= m_Parameters("LUT_ATTRIB"   )->asInt();	if( m_fValue >= Get_Shapes()->Get_Field_Count() )	{	m_fValue	= -1;	}
+		m_fNormal	= -1;
+
+		{
+			TSG_Data_Type	Type	= SG_Data_Type_is_Numeric(Get_Shapes()->Get_Field_Type(m_Parameters("LUT_ATTRIB")->asInt())) ? SG_DATATYPE_Double : SG_DATATYPE_String;
+
+			m_Parameters("LUT")->asTable()->Set_Field_Type(LUT_MIN, Type);
+			m_Parameters("LUT")->asTable()->Set_Field_Type(LUT_MAX, Type);
+		}
+		break;
+
+	case  2:	// CLASSIFY_DISCRETE
+	case  3:	// CLASSIFY_GRADUATED
+		m_fValue	= m_Parameters("METRIC_ATTRIB")->asInt();	if( m_fValue  >= Get_Shapes()->Get_Field_Count() )	{	m_fValue	= -1;	}
+		m_fNormal	= m_Parameters("METRIC_NORMAL")->asInt();	if( m_fNormal >= Get_Shapes()->Get_Field_Count() )	{	m_fNormal	= -1;	}
+		break;
 	}
 
-	if( m_Parameters("COLORS_TYPE")->asInt() == 1 )	// CLASSIFY_LUT
-	{
-		TSG_Data_Type	Type	= SG_Data_Type_is_Numeric(Get_Shapes()->Get_Field_Type(m_Parameters("LUT_ATTRIB")->asInt())) ? SG_DATATYPE_Double : SG_DATATYPE_String;
-
-		m_Parameters("LUT")->asTable()->Set_Field_Type(LUT_MIN, Type);
-		m_Parameters("LUT")->asTable()->Set_Field_Type(LUT_MAX, Type);
-	}
-
-	if( m_iColor >= Get_Shapes()->Get_Field_Count() )
-	{
-		m_iColor	= -1;
-	}
-
-	if( m_iColor < 0 && m_pClassify->Get_Mode() != CLASSIFY_UNIQUE )
+	if( m_fValue < 0 )
 	{
 		m_pClassify->Set_Mode(CLASSIFY_UNIQUE);
 	}
 
+	m_pClassify->Set_Unique_Color(m_pClassify->Get_Mode() == CLASSIFY_UNIQUE
+		? m_Parameters("UNISYMBOL_COLOR")->asColor()
+		: m_Parameters("NODATA_COLOR"   )->asColor()
+	);
+
+	m_bNoData	= m_Parameters("NODATA_SHOW")->asBool();
+
 	//-----------------------------------------------------
-	if( (m_iLabel = m_Parameters("LABEL_ATTRIB")->asInt()) >= Get_Shapes()->Get_Field_Count() )
+	if( (m_fLabel = m_Parameters("LABEL_ATTRIB")->asInt()) >= Get_Shapes()->Get_Field_Count() )
 	{
-		m_iLabel	= -1;
+		m_fLabel	= -1;
 	}
 
 	m_Label_Prec		= m_Parameters("LABEL_ATTRIB_PREC"        )->asInt  () - 2;
@@ -560,20 +585,61 @@ void CWKSP_Shapes::On_Parameters_Changed(void)
 //														 //
 ///////////////////////////////////////////////////////////
 
+//---------------------------------------------------------
+bool CWKSP_Shapes::Set_Metrics(int zField, int nField)
+{
+	if( zField < Get_Shapes()->Get_Field_Count() )
+	{
+		if( nField < Get_Shapes()->Get_Field_Count() )
+		{
+			m_Metrics.Create();
+
+			for(int i=0; i<Get_Shapes()->Get_Count(); i++)
+			{
+				double	z	= Get_Shapes()->Get_Record(i)->asDouble(zField);
+				double	n	= Get_Shapes()->Get_Record(i)->asDouble(nField);
+					
+				if( !Get_Shapes()->is_NoData_Value(z) && !Get_Shapes()->is_NoData_Value(n) && n != 0.0 )
+				{
+					m_Metrics.Add_Value(z / n);
+				}
+			}
+		}
+		else
+		{
+			m_Metrics.Create(Get_Shapes()->Get_Statistics(zField));
+		}
+
+		return( true );
+	}
+
+	return( false );
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
 //---------------------------------------------------------
 int CWKSP_Shapes::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter, int Flags)
 {
 	//-----------------------------------------------------
 	if( Flags & PARAMETER_CHECK_VALUES )
 	{
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "COLORS_TYPE")
-		||	!SG_STR_CMP(pParameter->Get_Identifier(), "METRIC_ATTRIB") )
+		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "COLORS_TYPE"  )
+		||	!SG_STR_CMP(pParameter->Get_Identifier(), "METRIC_ATTRIB")
+		||	!SG_STR_CMP(pParameter->Get_Identifier(), "METRIC_NORMAL") )
 		{
-			int		zField	= pParameters->Get_Parameter("METRIC_ATTRIB")->asInt();
+			Set_Metrics(
+				pParameters->Get_Parameter("METRIC_ATTRIB")->asInt(),
+				pParameters->Get_Parameter("METRIC_NORMAL")->asInt()
+			);
 
 			pParameters->Get_Parameter("METRIC_ZRANGE")->asRange()->Set_Range(
-				Get_Shapes()->Get_Minimum(zField),
-				Get_Shapes()->Get_Maximum(zField)
+				m_Metrics.Get_Minimum(),
+				m_Metrics.Get_Maximum()
 			);
 		}
 
@@ -591,6 +657,21 @@ int CWKSP_Shapes::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Paramete
 	//-----------------------------------------------------
 	if( Flags & PARAMETER_CHECK_ENABLE )
 	{
+		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "COLORS_TYPE") )
+		{
+			pParameters->Set_Enabled("NODATA_SHOW"  , pParameter->asInt() > 0);	// not 'single symbol'
+		}
+
+		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "NODATA_SHOW") )
+		{
+			pParameters->Set_Enabled("NODATA_COLOR" , pParameter->asBool());
+		}
+
+		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "METRIC_ATTRIB") )
+		{
+			pParameters->Set_Enabled("METRIC_NORMAL", pParameter->asInt() >= 0);
+		}
+
 		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "OUTLINE") )
 		{
 			pParameters->Set_Enabled("OUTLINE_COLOR", pParameter->asBool());
@@ -870,35 +951,50 @@ void CWKSP_Shapes::_LUT_Create(void)
 //---------------------------------------------------------
 wxString CWKSP_Shapes::Get_Value(CSG_Point ptWorld, double Epsilon)
 {
-	CSG_Shape		*pShape;
+	CSG_Shape	*pShape	= Get_Shapes()->Get_Shape(ptWorld, Epsilon);
 
-	if( (pShape = Get_Shapes()->Get_Shape(ptWorld, Epsilon)) != NULL )
+	if( pShape == NULL )
 	{
-		if( m_iColor >= 0 )
-		{
-			switch( m_pClassify->Get_Mode() )
-			{
-			case CLASSIFY_LUT:
-				return( m_pClassify->Get_Class_Name_byValue(pShape->asString(m_iColor)) );
+		return( _TL("") );
+	}
 
-			case CLASSIFY_METRIC:	default:
-				return( pShape->asString(m_iColor) );
-			}
-		}
-		else
+	if( m_fValue < 0 )
+	{
+		return( wxString::Format("%s: %d", _TL("Index"), pShape->Get_Index() + 1) );
+	}
+
+	if( m_pClassify->Get_Mode() == CLASSIFY_LUT )
+	{
+		return( m_pClassify->Get_Class_Name_byValue(pShape->asString(m_fValue)) );
+	}
+
+	if( !pShape->is_NoData(m_fValue) )
+	{
+		if( m_fNormal < 0 )
 		{
-			return( wxString::Format(wxT("%s: %d"), _TL("Index"), pShape->Get_Index() + 1) );
+			return( pShape->asString(m_fValue) );
+		}
+
+		if( !pShape->is_NoData(m_fNormal) && pShape->asDouble(m_fNormal) != 0.0 )
+		{
+			return( wxString::Format("%f", pShape->asDouble(m_fValue) / pShape->asDouble(m_fNormal)) );
 		}
 	}
 
 	return( _TL("") );
 }
 
+
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
-double CWKSP_Shapes::Get_Value_Range(void)
-{
-	return( m_iColor >= 0 ? Get_Shapes()->Get_Range(m_iColor) : 0.0 );
-}
+double CWKSP_Shapes::Get_Value_Minimum(void)	{	return( m_Metrics.Get_Minimum() );	}
+double CWKSP_Shapes::Get_Value_Maximum(void)	{	return( m_Metrics.Get_Maximum() );	}
+double CWKSP_Shapes::Get_Value_Range  (void)	{	return( m_Metrics.Get_Range  () );	}
+double CWKSP_Shapes::Get_Value_Mean   (void)	{	return( m_Metrics.Get_Mean   () );	}
+double CWKSP_Shapes::Get_Value_StdDev (void)	{	return( m_Metrics.Get_StdDev () );	}
 
 
 ///////////////////////////////////////////////////////////
@@ -910,7 +1006,7 @@ double CWKSP_Shapes::Get_Value_Range(void)
 //---------------------------------------------------------
 wxString CWKSP_Shapes::Get_Name_Attribute(void)
 {
-	return(	m_iColor < 0 || m_pClassify->Get_Mode() == CLASSIFY_UNIQUE ? SG_T("") : Get_Shapes()->Get_Field_Name(m_iColor) );
+	return(	m_fValue < 0 || m_pClassify->Get_Mode() == CLASSIFY_UNIQUE ? SG_T("") : Get_Shapes()->Get_Field_Name(m_fValue) );
 }
 
 
@@ -994,10 +1090,7 @@ void CWKSP_Shapes::On_Draw(CWKSP_Map_DC &dc_Map, int Flags)
 		{
 			for(iShape=0; iShape<Get_Shapes()->Get_Count(); iShape++)
 			{
-				if( (m_pClassify->Get_Mode() != CLASSIFY_METRIC || m_iColor < 0 || !Get_Shapes()->Get_Shape(iShape)->is_NoData(m_iColor)) )
-				{
-					_Draw_Shape(dc, Get_Shapes()->Get_Shape(iShape));
-				}
+				_Draw_Shape(dc, Get_Shapes()->Get_Shape(iShape));
 			}
 
 			if( _Chart_is_Valid() )
@@ -1010,7 +1103,7 @@ void CWKSP_Shapes::On_Draw(CWKSP_Map_DC &dc_Map, int Flags)
 		}
 
 		//-------------------------------------------------
-		if( (Flags & LAYER_DRAW_FLAG_NOLABELS) == 0 && m_iLabel >= 0 )
+		if( (Flags & LAYER_DRAW_FLAG_NOLABELS) == 0 && m_fLabel >= 0 )
 		{
 			int		iSize	= m_Parameters("LABEL_ATTRIB_SIZE_BY"  )->asInt();
 			double	dSize	= m_Parameters("LABEL_ATTRIB_SIZE_TYPE")->asInt() == 1 ?
@@ -1098,7 +1191,7 @@ void CWKSP_Shapes::_Draw_Label(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, int Poin
 {
 	if( pShape && dc_Map.m_rWorld.Intersects(pShape->Get_Extent()) != INTERSECTION_None )
 	{
-		wxString	Label(pShape->asString(m_iLabel, m_Label_Prec));	Label.Trim(true).Trim(false);
+		wxString	Label(pShape->asString(m_fLabel, m_Label_Prec));	Label.Trim(true).Trim(false);
 
 		if( !Label.IsEmpty() )
 		{
@@ -1235,17 +1328,40 @@ int CWKSP_Shapes::PenList_Get_Style(int Index)
 //---------------------------------------------------------
 bool CWKSP_Shapes::Get_Class_Color(CSG_Shape *pShape, int &Color)
 {
-	if( pShape && Get_Shapes() && m_iColor >= 0 )
+	//-----------------------------------------------------
+	if( m_fValue >= 0 )
 	{
-		if( m_pClassify->Get_Mode() == CLASSIFY_LUT && !SG_Data_Type_is_Numeric(Get_Shapes()->Get_Field_Type(m_iColor)) )
+		if( m_pClassify->Get_Mode() == CLASSIFY_LUT )
 		{
-			return( m_pClassify->Get_Class_Color_byValue(pShape->asString(m_iColor), Color) );
+			if( !SG_Data_Type_is_Numeric(Get_Shapes()->Get_Field_Type(m_fValue)) )
+			{
+				return( m_pClassify->Get_Class_Color_byValue(pShape->asString(m_fValue), Color) );
+			}
+			else
+			{
+				return( m_pClassify->Get_Class_Color_byValue(pShape->asDouble(m_fValue), Color) );
+			}
 		}
 
-		return( m_pClassify->Get_Class_Color_byValue(pShape->asDouble(m_iColor), Color) );
+		//-------------------------------------------------
+		if( !pShape->is_NoData(m_fValue) )
+		{
+			if( m_fNormal < 0 )	// don't normalize
+			{
+				return( m_pClassify->Get_Class_Color_byValue(pShape->asDouble(m_fValue), Color) );
+			}
+
+			if( !pShape->is_NoData(m_fNormal) && pShape->asDouble(m_fNormal) != 0.0 )
+			{
+				return( m_pClassify->Get_Class_Color_byValue(pShape->asDouble(m_fValue) / pShape->asDouble(m_fNormal), Color) );
+			}
+		}
 	}
 
-	return( false );
+	//-----------------------------------------------------
+	Color	= m_pClassify->Get_Unique_Color();
+
+	return( m_pClassify->Get_Mode() == CLASSIFY_UNIQUE );
 }
 
 
