@@ -320,8 +320,8 @@ void CWKSP_Shapes_Point::On_Parameters_Changed(void)
 
 	//-----------------------------------------------------
 	m_bOutline	= m_Parameters("OUTLINE")->asBool();
-	m_Pen		= wxPen(!m_bOutline ? m_Def_Color : Get_Color_asWX(m_Parameters("OUTLINE_COLOR")->asColor()), m_Parameters("OUTLINE_SIZE")->asInt(), wxPENSTYLE_SOLID);
-	m_Brush		= wxBrush(m_Def_Color, BrushList_Get_Style(m_Parameters("DISPLAY_BRUSH")->asInt()));
+	m_Pen		= wxPen(!m_bOutline ? m_pClassify->Get_Unique_Color() : Get_Color_asWX(m_Parameters("OUTLINE_COLOR")->asColor()), m_Parameters("OUTLINE_SIZE")->asInt(), wxPENSTYLE_SOLID);
+	m_Brush		= wxBrush(m_pClassify->Get_Unique_Color(), BrushList_Get_Style(m_Parameters("DISPLAY_BRUSH")->asInt()));
 }
 
 
@@ -337,13 +337,16 @@ int CWKSP_Shapes_Point::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Pa
 	//-----------------------------------------------------
 	if( Flags & PARAMETER_CHECK_VALUES )
 	{
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), wxT("COLORS_FONT")) )
+		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "COLORS_FONT") )
 		{
-			int		zField	= pParameters->Get_Parameter("METRIC_ATTRIB")->asInt();
+			Set_Metrics(
+				pParameters->Get_Parameter("METRIC_ATTRIB")->asInt(),
+				pParameters->Get_Parameter("METRIC_NORMAL")->asInt()
+			);
 
 			pParameters->Get_Parameter("METRIC_ZRANGE")->asRange()->Set_Range(
-				Get_Shapes()->Get_Minimum(zField),
-				Get_Shapes()->Get_Maximum(zField)
+				m_Metrics.Get_Minimum(),
+				m_Metrics.Get_Maximum()
 			);
 		}
 	}
@@ -351,12 +354,12 @@ int CWKSP_Shapes_Point::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Pa
 	//-----------------------------------------------------
 	if( Flags & PARAMETER_CHECK_ENABLE )
 	{
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), SG_T("DISPLAY_SYMBOL_TYPE")) )
+		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "DISPLAY_SYMBOL_TYPE") )
 		{
 			pParameters->Get_Parameter("DISPLAY_SYMBOL_IMAGE")->Set_Enabled(pParameter->asInt() == pParameter->asChoice()->Get_Count() - 1);
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), SG_T("LABEL_ATTRIB")) )
+		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "LABEL_ATTRIB") )
 		{
 			bool	Value	= pParameter->asInt() < Get_Shapes()->Get_Field_Count();
 
@@ -366,7 +369,7 @@ int CWKSP_Shapes_Point::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Pa
 			pParameters->Get_Parameter("LABEL_ALIGN_Y"     )->Set_Enabled(Value);
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), SG_T("SIZE_ATTRIB")) )
+		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "SIZE_ATTRIB") )
 		{
 			bool	Value	= pParameter->asInt() < Get_Shapes()->Get_Field_Count();
 
@@ -375,7 +378,7 @@ int CWKSP_Shapes_Point::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Pa
 			pParameters->Get_Parameter("SIZE_DEFAULT")->Set_Enabled(Value == false);
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), SG_T("LABEL_ANGLE_ATTRIB")) )
+		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "LABEL_ANGLE_ATTRIB") )
 		{
 			pParameters->Get_Parameter("LABEL_ANGLE")->Set_Enabled(pParameter->asInt() >= Get_Shapes()->Get_Field_Count());
 		}
@@ -438,61 +441,46 @@ inline bool CWKSP_Shapes_Point::Draw_Initialize(CWKSP_Map_DC &dc_Map, int &Size,
 	}
 
 	//-----------------------------------------------------
-	double	dSize;
-
-	if( m_iSize < 0 )	// default size
-	{
-		dSize	= m_Size;
-	}
-	else				// size by attribute value
-	{
-		dSize	= pShape->asDouble(m_iSize);
-
-		if( m_Size_Scale != 0 )	// scale to size range
-		{
-			dSize	= (dSize - m_Size_Min) * m_dSize + m_Size;
-		}
-	}
-
-	switch( m_Size_Type )
-	{
-	default:	dSize	*= dc_Map.m_Scale;		break;
-	case  1:	dSize	*= dc_Map.m_World2DC;	break;
-	}
-
-	Size	= (int)(0.5 + dSize);
-
-	if( Size <= 0 )
-	{
-		return( false );
-	}
-
-	//-----------------------------------------------------
-	int	Color;
-
 	if( Selection )
 	{
-		dc_Map.dc.SetBrush(wxBrush(m_Sel_Color_Fill, wxBRUSHSTYLE_SOLID));
-		dc_Map.dc.SetPen  (wxPen(m_Sel_Color, Selection == 1 ? 2 : 0, wxPENSTYLE_SOLID));
+		dc_Map.dc.SetBrush(wxBrush(m_Sel_Color_Fill, m_Brush.GetStyle()));
+		dc_Map.dc.SetPen(wxPen(m_Sel_Color, Selection == 1 ? 2 : 0, wxPENSTYLE_SOLID));
 	}
-	else if( Get_Class_Color(pShape, Color) )
+	else
 	{
+		int		Color;
+
+		if( !Get_Class_Color(pShape, Color) && !m_bNoData )
+		{
+			return( false );
+		}
+
 		if( !m_Brush.IsTransparent() )
 		{
-			wxBrush	Brush(m_Brush);	Brush.SetColour(SG_GET_R(Color), SG_GET_G(Color), SG_GET_B(Color));
-
-			dc_Map.dc.SetBrush(Brush);
+			wxBrush	Brush(m_Brush);	Brush.SetColour(SG_GET_R(Color), SG_GET_G(Color), SG_GET_B(Color)); dc_Map.dc.SetBrush(Brush);
 		}
 
 		if( !m_bOutline )
 		{
-			wxPen	Pen  (m_Pen  );	Pen  .SetColour(SG_GET_R(Color), SG_GET_G(Color), SG_GET_B(Color));
-
-			dc_Map.dc.SetPen(Pen);
+			wxPen	Pen  (m_Pen  );	Pen  .SetColour(SG_GET_R(Color), SG_GET_G(Color), SG_GET_B(Color)); dc_Map.dc.SetPen(Pen);
 		}
 	}
 
-	return( true );
+	//-----------------------------------------------------
+	double	dSize	= m_iSize < 0 ? m_Size : pShape->asDouble(m_iSize);
+
+	if( m_Size_Scale != 0 )	// scale to size range
+	{
+		dSize	= (dSize - m_Size_Min) * m_dSize + m_Size;
+	}
+
+	switch( m_Size_Type )
+	{
+	default: dSize *= dc_Map.m_Scale   ; break;
+	case  1: dSize *= dc_Map.m_World2DC; break;
+	}
+
+	return( (Size = (int)(0.5 + dSize)) > 0 );
 }
 
 //---------------------------------------------------------
