@@ -67,7 +67,7 @@
 #include "helper.h"
 
 #include "wksp_base_control.h"
-
+#include "wksp_data_manager.h"
 #include "wksp_table.h"
 
 #include "view_table.h"
@@ -139,6 +139,7 @@ wxString CWKSP_Table::Get_Description(void)
 
 	DESC_ADD_STR(_TL("Modified"         ), m_pObject->is_Modified() ? _TL("yes") : _TL("no"));
 	DESC_ADD_INT(_TL("Number of Records"), Get_Table()->Get_Count());
+	DESC_ADD_INT(_TL("Selected"         ), Get_Table()->Get_Selection_Count());
 
 	s	+= wxT("</table>");
 
@@ -165,10 +166,15 @@ wxMenu * CWKSP_Table::Get_Menu(void)
 		CMD_Menu_Add_Item(pMenu, false, ID_CMD_WKSP_ITEM_CLOSE);
 		CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_SAVE);
 		CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_SAVEAS);
+
 		if( PGSQL_has_Connections() )
-		{
 			CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_SAVETODB);
-		}
+
+		if( m_pObject->is_File_Native() && m_pObject->is_Modified() )
+			CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_RELOAD);
+
+		if( m_pObject->is_File_Native() )
+			CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_DEL_FILES);
 	}
 
 	CMD_Menu_Add_Item(pMenu,  true, ID_CMD_TABLES_SHOW);
@@ -234,6 +240,40 @@ bool CWKSP_Table::On_Command_UI(wxUpdateUIEvent &event)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+void CWKSP_Table::On_Create_Parameters(void)
+{
+	CWKSP_Data_Item::On_Create_Parameters();
+
+	//-----------------------------------------------------
+	m_Parameters.Add_Node(NULL, "NODE_TABLE", _TL("Display"), _TL(""));
+	m_Parameters.Add_Parameter(g_pData->Get_Parameter("TABLE_FLT_STYLE"   ));
+	m_Parameters.Add_Parameter(g_pData->Get_Parameter("TABLE_FLT_DECIMALS"));
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+void CWKSP_Table::On_DataObject_Changed(void)
+{
+	CWKSP_Data_Item::On_DataObject_Changed();
+
+	//-----------------------------------------------------
+	// ...
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
